@@ -1,10 +1,10 @@
 import functools
 import inspect
 from collections import Mapping
+from datetime import datetime
 
 from mgo_serializer.helpers import DictMapper
 
-
 __all__ = [
     'Empty',
     'BaseField',
@@ -310,14 +310,26 @@ class ObjectIdField(BaseField):
 
 class CustomField(BaseField):
 
-    def __init__(self):
+    def __init__(self, child=None):
+        self.child = child
         super().__init__(custom=True)
 
     def to_internal_value(self, data):
+        if data is not Empty:
+            if not self.child:
+                return data
+
+            if isinstance(data, list):
+                return [self.child.to_internal_value(item) for item in data]
+            return self.child.to_internal_value(data)
         return data
 
     def to_representation(self, value):
-        return value
+        if not self.child:
+            return value
+        if isinstance(value, list):
+            [self.child.to_representation(item) for item in value]
+        return self.child.to_representation(value)
 
     def to_protobuf(self, value):
         _repr = self.to_representation(value)
@@ -325,3 +337,87 @@ class CustomField(BaseField):
             return None
         return _repr
 
+
+class ListField(BaseField):
+
+    def __init__(self, type=None, **kwargs):
+        self.child = type
+        super().__init__(**kwargs)
+
+    def to_internal_value(self, data):
+        if data is not Empty:
+            if not self.child:
+                return data
+            return [self.child.to_internal_value(item) for item in data]
+        return data
+
+    def to_representation(self, value):
+        if not self.child:
+            return value
+        return [self.child.to_representation(item) for item in value]
+
+    def to_protobuf(self, value):
+        _repr = self.to_representation(value)
+        if _repr is None:
+            return None
+        return _repr
+
+
+class DictField(BaseField):
+
+    def __init__(self, type=None, **kwargs):
+        self.child = type
+        super().__init__(**kwargs)
+
+    def to_internal_value(self, data):
+        if data is not Empty:
+            if not self.child:
+                return data
+            return {
+                key: self.child.to_internal_value(value)
+                for key, value in data.items()
+            }
+        return data
+
+    def to_representation(self, value):
+        if not self.child:
+            return value
+        return {
+            key: self.child.to_representation(item)
+            for key, item in value.items()
+        }
+
+    def to_protobuf(self, value):
+        _repr = self.to_representation(value)
+        if _repr is None:
+            return None
+        return _repr
+
+
+class DateTimeField(BaseField):
+
+    def __init__(self, format=None, **kwargs):
+        self.format = format
+        super().__init__(**kwargs)
+
+    def to_internal_value(self, data):
+        if data is not Empty:
+            if self.format:
+                data = datetime.strptime(data, self.format)
+            else:
+                data = datetime.fromtimestamp(data)
+            return data
+        return data
+
+    def to_representation(self, value):
+        if value is not None:
+            if self.format:
+                return value.strftime(self.format)
+            return value
+        return value
+
+    def to_protobuf(self, value):
+        _repr = self.to_representation(value)
+        if _repr is None:
+            return None
+        return _repr
