@@ -110,10 +110,19 @@ class BaseSerializer(BaseField):
     @property
     def protobuf(self):
         """
-        Returns the serialized data on the serializer.
+        Returns the serialized data on the serializer as protobuf message.
 
-        :see: https://www.django-rest-framework.org/api-guide/serializers/#data
+        :return: Return list of protobuf messages
+        :rtype: list
         """
+
+        if not self.pb:
+            raise AttributeError(
+                'Protobuf is not defined in {!r} serializer. '
+                'You can define it in meta variable with `schema` key.'
+                .format(self.child.__class__.__name__)
+            )
+
         self._protobuf = self.to_representation(self.validated_data)
         protobuf_list = []
         for data in self._protobuf:
